package de.docutain.docutain_sdk

import android.app.Activity
import android.content.Context
import android.content.Intent
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.PluginRegistry

import de.docutain.sdk.DocutainSDK.initSDK
import de.docutain.sdk.DocutainSDK.getLastError
import de.docutain.sdk.DocutainSDK.getTraceFile
import de.docutain.sdk.ui.DocumentScanner
import de.docutain.sdk.Document

import java.io.File

/** DocutainSdkPlugin */
class DocutainSdkPlugin: FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var context : Context
  private var act: android.app.Activity? = null
  private lateinit var result: Result
  val SCAN_DOCUMENT_RESULT_CODE = 1

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    context = flutterPluginBinding.applicationContext
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "docutain_sdk")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    this.result = result //saves the result to call it when the user
    if (call.method == "initSDK") {
      val licenseKey : String? = call.argument("licenseKey");
      val rc = initSDK(context as android.app.Application, licenseKey!!)
      result.success(rc)
    }  else if (call.method == "getLastError") {
      result.success(getLastError())
    } else if (call.method == "getTraceFile") {
      val traceFile = getTraceFile()
      result.success(traceFile.path)
    }  else if (call.method == "scanDocument") {
      if(act != null){
        val nativeScanConfig = de.docutain.sdk.ui.DocumentScannerConfiguration()
        nativeScanConfig.allowCaptureModeSetting = call.argument("allowCaptureModeSetting")!!
        val intent = DocumentScanner.newScanIntent(context, nativeScanConfig)
        act!!.startActivityForResult(intent, SCAN_DOCUMENT_RESULT_CODE)
      } else{
        result.success(false)
      }
    }else if (call.method == "writePDF") {
      val path : String? = call.argument("path");
      val fileName : String? = call.argument("fileName");
      val overwrite : Boolean? = call.argument("overwrite");
      val returnFile = Document.writePDF(java.io.File(path!!, fileName!!), overwrite!!);
      if(returnFile != null){
        return result.success(returnFile.parent!! + "/" + returnFile.name);
      } else{
        return result.success(null);
      }
    }  else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    act = binding.activity
    binding.addActivityResultListener(this)
  }
  override fun onDetachedFromActivityForConfigChanges() {
    act = null
  }
  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    act = binding.activity
    binding.addActivityResultListener(this)
  }
  override fun onDetachedFromActivity() {
    act = null
  }
  override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
    if (requestCode == SCAN_DOCUMENT_RESULT_CODE) {
      result.success(if (resultCode == Activity.RESULT_OK) true else false)
      return true
    }
    return false
  }
}
