import 'dart:io';

import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'docutain_sdk_method_channel.dart';
import 'docutain_sdk_ui.dart';

abstract class DocutainSdkPlatform extends PlatformInterface {
  /// Constructs a DocutainSdkPlatform.
  DocutainSdkPlatform() : super(token: _token);

  static final Object _token = Object();

  static DocutainSdkPlatform _instance = MethodChannelDocutainSdk();

  /// The default instance of [DocutainSdkPlatform] to use.
  ///
  /// Defaults to [MethodChannelDocutainSdk].
  static DocutainSdkPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [DocutainSdkPlatform] when
  /// they register themselves.
  static set instance(DocutainSdkPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<bool> initSDK(String licenseKey) {
    throw UnimplementedError('initSDK() has not been implemented.');
  }

  Future<String> getLastError() {
    throw UnimplementedError('getLastError() has not been implemented.');
  }

  Future<File?> getTraceFile() {
    throw UnimplementedError('getTraceFile() has not been implemented.');
  }

  Future<bool> scanDocument(DocumentScannerConfiguration scanConfig) {
    throw UnimplementedError('scanDocument() has not been implemented.');
  }

  Future<File?> writePDF(String path, String fileName, bool overwrite) {
    throw UnimplementedError('writePDF() has not been implemented.');
  }
}
